@@ -1,14 +1,26 @@
 from sklearn.ensemble import RandomForestRegressor
-from .base_model import base_model
+from nextstep.model.base_model import base_model
 
 
 class random_forest(base_model):
+    """random forest class."""
     def __init__(self, config):
+        """constructor method
+
+        :param config: configuration for adaboost model
+        :type config: python dictionary
+        """
         super().__init__()
         self._config = config
         self._model = None
     
     def build_model(self, data):
+        """building the random forest model, including train-test split and model evaluation.
+
+        :param data: dataset
+        :type data: pandas dataframe
+        :return: fitted adaboost model
+        """
         print('Building random forest model.')
         model = RandomForestRegressor(n_estimators = self._config['n_estimators'], 
                                       bootstrap = self._config['bootstrap'],
@@ -28,20 +40,11 @@ class random_forest(base_model):
         return model
     
     def predict(self, X_new):
+        '''use fitted module for prediction.
+
+        :param X_new: data of shape (n_samples, n_features)
+        :type X_new: array-like
+        '''
         return self._model.predict(X_new)
 
     
-if __name__ == "__main__":
-    import pandas as pd
-    data = pd.read_csv("../../development/Feature_Mart/feature_mart_merged_1.csv")
-    data = data.drop(['date','demand_clusters','moonrise','moonset','sunrise','sunset'], axis = 1)
-    random_forest_shell = random_forest({
-                                    'label_column' : 'USEP',
-                                    'train_size' : 0.8,
-                                    'seed' : 33,
-                                    'n_estimators' : 5,
-                                    'bootstrap' : True,
-                                    'criterion' : 'mse',
-                                    'max_features' : 'sqrt'})
-    
-    random_forest_shell.build_model(data)
